// 在ribbon中 自定义组件
function DateTimePicker() {
    GC.Spread.Sheets.Designer.AtomicComponentBase.call(this, ...arguments)
};
// 继承AtomicComponentBase
DateTimePicker.prototype = new GC.Spread.Sheets.Designer.AtomicComponentBase();

// 获取模板
DateTimePicker.prototype.getTemplate = function(options) {
    return `
        <div class="input-append date" style="margin-top: 35px;">
            <input size="20" class ='form_datetime' type="text">
        </div>
    `;
}

// 挂载
DateTimePicker.prototype.onMounted = function(host, options) {
    // 初始化第三方组件：datepicker
    $(".form_datetime", host).datepicker(options);
    
    // 修改时触发raiseValueChanged事件。
    $(".form_datetime", host).change((e) => {
        this.raiseValueChanged()
    })
}

// 刷新组件UI
DateTimePicker.prototype.onValueChanged = function(prevValue, nextValue, host, options) {
    $(".form_datetime", host).datepicker('setDate', (nextValue && nextValue.toLocaleString) ? nextValue.toLocaleString('en-us', {
        year: 'numeric',
        month: 'numeric',
        day: 'numeric'
    }) : "");
}

// 组件值更改时调用此函数，获取组件提供给designer使用
DateTimePicker.prototype.updateValue = function(host, options) {
    var value = $(".form_datetime", host).datepicker('getDate')
    if (value) {
        return new Date(value);
    }
    return null;
}

// 将自定义组件注册到designer中
GC.Spread.Sheets.Designer.Designer.RegisterComponent("DateTimePicker", DateTimePicker);

// 定义命令
var dateTime = {
    title: "set time",
    text: "设置时间",
    commandName: "dateTime",
    type: 'DateTimePicker',
    execute: (designer, propertyName, value) => {
        let sheet = designer.getWorkbook().getActiveSheet();
        if (sheet) {
            var row = sheet.getActiveRowIndex();
            var col = sheet.getActiveColumnIndex();
            sheet.setValue(row, col, value);
        }
    },
    getState: (designer) => { 
        var spread = designer.getWorkbook();
        var sheet = spread.getActiveSheet();
        var row = sheet.getActiveRowIndex();
        var col = sheet.getActiveColumnIndex();
        var value = sheet.getValue(row, col);
        return value;
    }
}

// 在designer中配置
var config = JSON.parse(JSON.stringify(GC.Spread.Sheets.Designer.DefaultConfig));
config.commandMap = {
    cmdDateTimePicker: dateTime
}
var command = {
    text: "日期选择器",
    id: "time",
    buttonGroups: [{
        label: "日期",
        commandGroup: {
            direction: "horizontal",
            commands: ["cmdDateTimePicker"]
        }
    }]
};
config.ribbon.unshift(command);